<h1>select a FAQ category</h1>
{% for category in categories %}
    <h3><a href="{% url 'faq:category_detail' category.slug %}">{{category.name}}</a></h3>
    {% if category.description %}
        <p>{{category.description}}</p>
    {% endif %}
<hr>
{% endfor %}
