<h1>choose a FAQ Question</h1>
{% for question in questions %}
    <h3><a href="{% url 'faq:question_detail' question.slug %}">{{question.question}}</a></h3>
{% endfor %}

{% if can_add_question %}
    <hr>
    <a href="{% url 'faq:add_question' %}">add question</a>
{% endif %}

